# MCNP Input Reader

MCNP Input Reader is a python package developed in order to facilitate the modifications and the check integrity 
of large mcnp input files.

## Install

```shell
pip install mcnp-input-reader
```

## TODO

A lot of things...

## Example

Example taken from [here](https://www.utoledo.edu/med/depts/radther/pdf/MCNP5%20practical%20examples%20lecture%207%20companion.pdf) 

